Skip to main contentModule traits
Source - AbstractSimulator
- Interface for simulating DEVS models. All DEVS models must implement this trait.
- AsyncInput
- Interface for handling input events in an asynchronous DEVS simulation.
- Bag
- Trait that defines the methods that a DEVS event bag set must implement.
- Component
- Interface for DEVS components. All DEVS components must implement this trait.
- PartialAtomic
- Partial interface for DEVS atomic models.
It is used as a helper trait to implement the
crate::Atomic trait.